pub struct Region {
pub open_fence: Span,
pub content: Span,
pub close_fence: Span,
pub body: Span,
}Expand description
A located embed region in host-file byte coordinates (the content is not
parsed). body is the host prose outside the fences — the suffix after the
close fence for frontmatter, the prefix before the open fence for endmatter.
Fields
open_fence: Spancontent: Spanclose_fence: Spanbody: SpanTrait Implementations